fs.ensembl.stability(X, Y, method, k = 10, p = 0.9, f = ceiling(ncol(X)/10), bags = 40, aggregation.metric = "CLA", stability.metric = "jaccard", optimize = TRUE, optimize.resample = FALSE, tuning.grid = NULL, k.folds = if (optimize) 10 else NULL, repeats = if (k.folds == "LOO") NULL else if (optimize) 3 else NULL, resolution = if (optimize) 3 else NULL, metric = "Accuracy", model.features = FALSE, allowParallel = FALSE, verbose = "none", ...)"plsda" (Partial Least Squares
Discriminant Analysis), "rf" (Random Forest), "gbm"
(Gradient Boosting Machine), "svm" (Support Vector Machines),
"glmnet" (Elastic-net Generalized Linear Model),
and "pam" (Prediction Analysis of Microarrays)"f = ceiling(ncol(variables)/10)".
If rank correlation is desired, set "f = NULL""bags = 40""CLA"
(Complete Linear), "EM" (Ensemble Mean), "ES"
(Ensemble Stability), and "EE" (Ensemble Exponential)"jaccard" (Jaccard Index/Tanimoto Distance),
"sorensen" (Dice-Sorensen's Index), "ochiai" (Ochiai's Index),
"pof" (Percent of Overlapping Features), "kuncheva"
(Kuncheva's Stability Measures), "spearman" (Spearman Rank
Correlation), and "canberra" (Canberra Distance)"optimize = TRUE""optimize.resample = FALSE" - Only
one optimization run, subsequent models use initially determined parameters"tuning.grid = NULL" lets function
create grid determined by "res""LOO" for leave-one-out cross-validation.
Default "k.folds = 10""repeats = 3""res = 3""Accuracy" (Predication Accuracy), "Kappa" (Kappa Statistic),
and "AUC-ROC" (Area Under the Curve - Receiver Operator Curve)"model.features = FALSE"allowParallel = FALSE"optimize.resample = TRUE" then returns
list of optimized parameters for each bagging and bootstrap interation."optimize.resample = TRUE" then
returns list of optimized parameters for each bootstrap of the bagged models
refit to aggregated selected features.## Not run:
# fits <- fs.ensembl.stability(vars,
# groups,
# method = c("plsda", "rf"),
# f = 10,
# k = 3,
# k.folds = 10,
# verbose = 'none')
# ## End(Not run)
Run the code above in your browser using DataLab